@@ -272,7 +272,7 @@ namespace eval QEntryBox {
 	wm title $wn $title
 	pack [message $wn.message -text $message -width $width]
 	pack [entry $wn.entry]
-	regsub -all -- "%g" $script "\[$wn.entry get]" script
+	set script [parseformat $script [list [list g "\[$wn.entry get]"]]
 	set script "\{$script; destroy $wn\}"
 	bind $wn <<Enter>> "eval $script"
 	bind $wn <KeyPress-Escape> "destroy $wn"
@@ -290,7 +290,7 @@ namespace eval QPasswordBox {
 	wm title $wn $title
 	pack [message $wn.message -text $message -width $width]
 	pack [entry $wn.entry -show *]
-	regsub -all -- "%g" $script "\[$wn.entry get]" script
+	set script [parseformat $script [list [list g "\[$wn.entry get]"]]
 	set script "\{$script; destroy $wn\}"
 	bind $wn <<Enter>> "eval $script"
 	bind $wn <KeyPress-Escape> "destroy $wn"
