@@ -87,7 +87,7 @@ void tdcc::handle(int mask) {
 	      strcat(buffer,temp);
 	      usedata();
 	    } else {
-	      echo("Buffer Overrun in DCCCHAT (Please contact author at patearl@pobox.com)",".main",1);
+	      echo("Buffer Overrun in DCCCHAT (Please contact author at quirc@patearl.net)",".main",1);
 	    }
 	  } else {
 	    disconnect();
